@@ -35,6 +35,7 @@
 #endif
 
 #include <dbus/dbus-glib.h>
+#include <mce/dbus-names.h>
 
 #if HILDON == 1
 #include <hildon/hildon.h>
@@ -316,9 +317,9 @@ void hw_event_handler(osso_hw_state_t *state, MainView *mainview) {
 
 	if ((state->shutdown_ind)	/* system shutdown */
 			|| (state->system_inactivity_ind)) {	/* system sleeping */
-        save_mod_file(mainview);
+		save_mod_file(mainview);
 		close_file(mainview);
-        return;
+		return;
 	}
 	if (state->memory_low_ind) {	/* memory low... */
 		unshow_rec(mainview);	/* close the rec window... changes not saved... */
@@ -480,11 +481,17 @@ void callback_fullscreen( GtkAction * action, gpointer data ) {
 
 /* filter */
 
-void callback_filter( GtkAction * action, MainView *mainview ) {
-    gchar *ftxt = NULL;
+void callback_filter(GtkWidget *widget, MainView *mainview ) {
+    const gchar *ftxt = NULL;
     GList *onrec=NULL;
-    
-    g_object_get(G_OBJECT(action), "text", &ftxt, NULL);
+
+#if MAEMO_VERSION_MAJOR < 5
+	ftxt = gtk_entry_get_text(GTK_ENTRY(widget));
+#else
+	ftxt = hildon_entry_get_text(HILDON_ENTRY(widget));
+#endif
+//    g_object_get(G_OBJECT(action), "text", &ftxt, NULL);
+	g_printerr("filter -%s-\n", ftxt);
     
     onrec=g_list_first(recs);
     if (ftxt[0] == '\0') { /* no filter, skip= none */
@@ -545,3 +552,19 @@ void callback_export ( GtkAction * action, MainView *mainview ) {
         }
     }
 }
+
+DBusHandlerResult dbus_handle_mce_message(DBusConnection *con, DBusMessage *msg, MainView *mainView ) {
+	DBusMessageIter iter;
+	dbus_bool_t value;
+
+	if (dbus_message_is_signal(msg, MCE_SIGNAL_IF, MCE_INACTIVITY_SIG)) {
+		if (dbus_message_iter_init(msg, &iter)) {
+			dbus_message_iter_get_basic(&iter, &value);
+			if (value) {
+				interfaceCallLastItem(mainView) ;
+			}
+			g_printerr("INFO: New activity status is now: %d\n", value);
+		}
+	}
+	return DBUS_HANDLER_RESULT_NOT_YET_HANDLED;
+}
