@@ -47,7 +47,7 @@ void callback_change_password( GtkAction * action, MainView *mainview );
 /* fullscreen */
 void callback_fullscreen ( GtkAction * action, gpointer data );
 /* filter */
-void callback_filter ( GtkAction * action, MainView *mainview );
+void callback_filter(GtkWidget *widget, MainView *mainview );
 /* export */
 void callback_export ( GtkAction * action, MainView *mainview );
 /* grid activated */
@@ -63,5 +63,6 @@ gboolean exit_event_handler( GtkWidget *widget, GdkEvent  *event, MainView *main
 
 void callback_buffer_changed(GtkTextBuffer *buffer, MainView *mainview) ;
 gboolean callback_tag_event(GtkTextTag *tag, GObject *object, GdkEvent *event, GtkTextIter *iter, MainView *mainview);
+DBusHandlerResult dbus_handle_mce_message(DBusConnection *con, DBusMessage *msg, MainView *mainView);
 
 #endif
