@@ -33,6 +33,7 @@
 #include <libgnomevfs/gnome-vfs.h>
 #include <string.h>
 
+#define SEP_V1 "\xAD"
 
 /* private */
 char readbytes(MainView* mainview, GnomeVFSHandle *handle, unsigned char *ptr, unsigned int bytes);
@@ -335,7 +336,11 @@ void write_pwsafe_file(MainView* main) {
 	}
 	/* close file */
 	if (GNOME_VFS_OK==gnome_vfs_close(handle)) {	/* Only replace original file if it closed OK */
-		gnome_vfs_move(file_name_new, main->file_name, TRUE);
+		if (GNOME_VFS_OK==gnome_vfs_move(file_name_new, main->file_name, TRUE)) {
+			main->last_file=main->file_name;
+		} else {
+			interface_error(PWSAFE_ERROR_SAVE_FAILED, main);
+		}			
 	} else {
 		interface_error(PWSAFE_ERROR_SAVE_FAILED, main);
 	}
@@ -408,8 +413,23 @@ gboolean pwsafe_file_open_error(MainView *mainview, GnomeVFSResult vfs_result) {
 	return FALSE;
 }
 
+
+void getV1UserTitle(char *buffer, rec *entry) {
+	gchar ** list = g_strsplit(buffer, SEP_V1, 3);
+	if (g_strv_length(list) > 1) {
+		entry->user=g_strndup(list[1], strlen(list[1])-1);
+	} else {
+		entry->user=g_strdup("DefaultUser");
+	}
+	entry->title=g_strdup(list[0]);
+	g_strfreev(list);
+	g_free(buffer);
+}
+
 void read_pwsafe_file(MainView* mainview) {
+	gchar *msg;
 	gboolean valid = FALSE;
+	gboolean v2 = TRUE;
 	/* get password */
 	gchar *file_utf8;
 	g_assert(mainview!=NULL);
@@ -418,7 +438,7 @@ void read_pwsafe_file(MainView* mainview) {
 	mainview->pass=get_password(mainview, file_utf8);
 	g_free(file_utf8);
 	
-	if (mainview->pass) {
+	if (mainview->pass && mainview->pass[0]) {
 		GnomeVFSResult vfs_result;
 		GnomeVFSHandle *handle = NULL;
 		GnomeVFSFileInfo finfo;
@@ -462,63 +482,102 @@ void read_pwsafe_file(MainView* mainview) {
 								if (buffer!=NULL) {
 									fileversion=buffer;
 									if (strcmp("2.0", fileversion)!=0) {
-										msgbox(mainview, "Unexpected file version (not 2.0)");
+										v2 = FALSE;
+//										msg = g_strdup(_("Reading file with version (1.x) \n Will write in 2.0 format"));
+//										msgbox(mainview, msg);
+//										g_free(msg);
+										g_printerr("Reading file with version (1.x) \n Will write in 2.0 format");
+										entry=g_malloc0(sizeof(rec));
+										entry->uuid=entry->group=entry->title=entry->user=entry->notes=entry->password=NULL;
+										new_uuid(entry);
+										getV1UserTitle(filetitle, entry);
+										entry->password=g_strndup(buffer, strlen(buffer)-1);
 									}
-									buffer=readcbc(mainview, handle, &blowCTX, iv, &buffer_len, &rec_type);
-									mainview->preferences=buffer;
-									/* create an entry record, with everything pointing to an empty string */
-									entry=g_malloc0(sizeof(rec));
-									entry->uuid=entry->group=entry->title=entry->user=entry->notes=entry->password=NULL;
 									recs=NULL;
-									valid = TRUE;
-									/* read and decrypt the blocks. store the settings for each one, and write them to the tree on each END */
 									buffer=readcbc(mainview, handle, &blowCTX, iv, &buffer_len, &rec_type);
-									do {
-										switch (rec_type) {
-											case UUID:
-												if (buffer_len!=16) {
-													if (!uuiderr) {
-														msgbox(mainview, "file error - UUID not 16 bytes. Recreating");
-													}
-													uuiderr=TRUE;
-													g_free(buffer);
-													new_uuid(entry);
-												} else {
-													entry->uuid=buffer;
-												}
-												break;
-											case GROUP:
-												entry->group=buffer;
-												break;
-											case TITLE:
-												entry->title=buffer;
-												break;
-											case USER:
-												entry->user=buffer;
-												break;
-											case NOTES:
-												entry->notes=buffer;
-												break;
-											case PASSWORD:
-												entry->password=buffer;
-												break;
-											case END:
-												g_free(buffer);
-												recs=g_list_insert_sorted(recs, entry, (GCompareFunc) rec_comparer);
-												entry=g_malloc0(sizeof(rec));
-												entry->uuid=entry->group=entry->title=entry->user=entry->notes=entry->password=NULL;
-												break;
-											default: /* unknown block... just delete it and move on. */
-												if (buffer_len>0) {
-													g_free(buffer);
-												}
-										}
-										gnome_vfs_tell(handle, &filepos);
-										if (finfo.size<=filepos) {
-											break;
+									if (v2) {
+										mainview->preferences=buffer;
+									} else {
+										if (buffer != NULL) {
+											entry->notes=buffer;
+											entry->group=g_strdup("Group");
+											recs=g_list_insert_sorted(recs, entry, (GCompareFunc) rec_comparer);
 										}
+									}
+									valid = TRUE;
+									gnome_vfs_tell(handle, &filepos);
+									if (finfo.size>filepos) {
+										/* create an entry record, with everything pointing to an empty string */
+										entry=g_malloc0(sizeof(rec));
+										entry->uuid=entry->group=entry->title=entry->user=entry->notes=entry->password=NULL;
+										/* read and decrypt the blocks. store the settings for each one, and write them to the tree on each END */
 										buffer=readcbc(mainview, handle, &blowCTX, iv, &buffer_len, &rec_type);
-									} while (buffer!=NULL);
+										do {
+											if (v2) {
+												switch (rec_type) {
+													case UUID:
+														if (buffer_len!=16) {
+															if (!uuiderr) {
+																msgbox(mainview, "file error - UUID not 16 bytes. Recreating");
+															}
+															uuiderr=TRUE;
+															g_free(buffer);
+															new_uuid(entry);
+														} else {
+															entry->uuid=buffer;
+														}
+														break;
+													case GROUP:
+														entry->group=buffer;
+														break;
+													case TITLE:
+														entry->title=buffer;
+														break;
+													case USER:
+														entry->user=buffer;
+														break;
+													case NOTES:
+														entry->notes=buffer;
+														break;
+													case PASSWORD:
+														entry->password=buffer;
+														break;
+													case END:
+														g_free(buffer);
+														recs=g_list_insert_sorted(recs, entry, (GCompareFunc) rec_comparer);
+														entry=g_malloc0(sizeof(rec));
+														entry->uuid=entry->group=entry->title=entry->user=entry->notes=entry->password=NULL;
+														break;
+													default: /* unknown block... just delete it and move on. */
+														if (buffer_len>0) {
+															g_free(buffer);
+														}
+												}
+											} else {
+												if (buffer != NULL) {
+													new_uuid(entry);
+													getV1UserTitle(buffer, entry);
+													buffer=readcbc(mainview, handle, &blowCTX, iv, &buffer_len, &rec_type);
+													if (buffer != NULL) {
+														entry->password=buffer;
+														buffer=readcbc(mainview, handle, &blowCTX, iv, &buffer_len, &rec_type);
+														if (buffer != NULL) {
+															entry->notes=buffer;
+															entry->group=g_strdup("Group");
+															recs=g_list_insert_sorted(recs, entry, (GCompareFunc) rec_comparer);
+															entry=g_malloc0(sizeof(rec));
+															entry->uuid=entry->group=entry->title=entry->user=entry->notes=entry->password=NULL;
+														}
+													}
+												}
+											}
+											gnome_vfs_tell(handle, &filepos);
+											if (finfo.size<=filepos) {
+												break;
+											}
+											buffer=readcbc(mainview, handle, &blowCTX, iv, &buffer_len, &rec_type);
+										} while (buffer!=NULL);
+									}
 									g_free(fileversion);
 									populate_treeView(mainview);
 								}
@@ -538,5 +597,5 @@ void read_pwsafe_file(MainView* mainview) {
 	}
 	// Fred manage interface
 	interface_show_state(mainview);
-
 }
+
