@@ -46,6 +46,7 @@
 #include <hildon-widgets/hildon-get-password-dialog.h>
 #endif
 
+#include <mce/dbus-names.h>
 
 #define MAIN_TEXT MAIN_VIEW_NAME
 
@@ -76,6 +77,8 @@ MainView* interface_main_view_new( AppData *data ) {
 	result->rec_win=NULL;
 	result->file_edited = FALSE;
 	result->file_name=NULL;
+/* pasword unset */
+	result->pass=NULL;
 /* Store handle to app's data to view's data and hildon appview */
 	result->data = data;
 	data->main_view = HILDON_WINDOW(hildon_window_new()); 
@@ -90,10 +93,15 @@ MainView* interface_main_view_new( AppData *data ) {
 	gtk_widget_grab_focus( GTK_WIDGET(result->treeView ));
 	/* attach handlers */
 	osso_hw_set_event_cb( data->osso, NULL,(osso_hw_cb_f *) hw_event_handler, result);
-//	osso_application_set_exit_cb( data->osso, exit_event_handler, result);
 	g_signal_connect (G_OBJECT(data->main_view), "delete_event", G_CALLBACK(exit_event_handler), result);	/* top right X, etc. */
 	g_signal_connect(G_OBJECT(result->data->main_view), "key_press_event", G_CALLBACK(callback_key_press), result);
-	
+
+	/* Get the system DBus connection */
+	DBusConnection *con = osso_get_sys_dbus_connection(data->osso);
+	/* Add the callback, which should be called, once the device is rotated */
+	dbus_bus_add_match(con, MCE_MATCH_RULE, NULL);
+	dbus_connection_add_filter(con, dbus_handle_mce_message, result, NULL);
+
 #if MAEMO_VERSION_MAJOR >= 5
 	result->regexHttp = g_regex_new("http(s?)://[\\S]+", G_REGEX_CASELESS, 0, NULL);
 	result->regexWww = g_regex_new("www\\.[\\S]+", G_REGEX_CASELESS, 0, NULL);
@@ -310,7 +318,7 @@ void populate_treeView (MainView *main) {
       	    }
 	    onrec=g_list_next(onrec);
 	}
-	interface_show_state(main);
+//	interface_show_state(main);
 }
 
 
@@ -521,7 +529,7 @@ void interface_show_state(MainView *main) {
     	interface_show_item(main->change_password, fopen);
 	interface_show_item(main->add_item, fopen);
 	
-	if (GTK_IS_WIDGET(main->new_tb)) {	/* ignore toolbar if it's not there (eg. during app close) */
+	if (GTK_IS_WIDGET(main->add_tb)) {	/* ignore toolbar if it's not there (eg. during app close) */
 #if MAEMO_VERSION_MAJOR < 5
 		gtk_widget_set_sensitive(GTK_WIDGET(main->new_tb), !fopen);
 		gtk_widget_set_sensitive(GTK_WIDGET(main->open_tb), !fopen);
@@ -531,7 +539,7 @@ void interface_show_state(MainView *main) {
 #endif
 		gtk_widget_set_sensitive(GTK_WIDGET(main->change_password_tb), fopen);
 		gtk_widget_set_sensitive(GTK_WIDGET(main->add_tb), fopen);
-		gtk_widget_set_sensitive(GTK_WIDGET(main->filter_tb), fopen);
+		gtk_editable_set_editable(GTK_EDITABLE(main->filter_tb), fopen);
 	}
 }
 
@@ -574,12 +582,12 @@ static void create_toolbar ( MainView *main ) {
 	main->save_tb = gtk_tool_button_new_from_stock(GTK_STOCK_SAVE);
 	main->saveas_tb = gtk_tool_button_new_from_stock(GTK_STOCK_SAVE_AS);
 	main->separator_tb1 = gtk_separator_tool_item_new();
+	main->fullscreen_tb = gtk_tool_button_new_from_stock( GTK_STOCK_ZOOM_FIT );
+    main->separator_tb3 = gtk_separator_tool_item_new();
 #endif
 	main->add_tb = gtk_tool_button_new_from_stock(GTK_STOCK_ADD);
 	main->change_password_tb = gtk_tool_button_new_from_stock(GTK_STOCK_CONVERT);
 	main->separator_tb2 = gtk_separator_tool_item_new();
-	main->fullscreen_tb = gtk_tool_button_new_from_stock( GTK_STOCK_ZOOM_FIT );
-    main->separator_tb3 = gtk_separator_tool_item_new();
     
     /* create filter text entry in a container */
     main->filter_item_tb = gtk_tool_item_new();
@@ -595,7 +603,7 @@ static void create_toolbar ( MainView *main ) {
     gtk_container_add( GTK_CONTAINER( main->filter_item_tb ) , main->filter_tb);
 	
     /* Insert items to toolbar */
-#if MAEMO_VERSION_MAJOR >= 5
+#if MAEMO_VERSION_MAJOR < 5
 	gtk_toolbar_insert ( GTK_TOOLBAR(main->toolbar), main->new_tb, -1);
 	gtk_toolbar_insert ( GTK_TOOLBAR(main->toolbar), main->open_tb, -1);
 	gtk_toolbar_insert ( GTK_TOOLBAR(main->toolbar), main->close_tb, -1);
@@ -623,7 +631,7 @@ static void create_toolbar ( MainView *main ) {
 #endif
 	g_signal_connect(G_OBJECT(main->add_tb), "clicked", G_CALLBACK(callback_add_entry), main);
 	g_signal_connect(G_OBJECT(main->change_password_tb), "clicked", G_CALLBACK(callback_change_password), main);
-	g_signal_connect(G_OBJECT(main->filter_tb), "activate", G_CALLBACK(callback_filter), main);
+	g_signal_connect(G_OBJECT(main->filter_tb), "changed", G_CALLBACK(callback_filter), main);
 	
 	/* Attach toolbar to main view */
 	hildon_window_add_toolbar(main->data->main_view, GTK_TOOLBAR(main->toolbar)); 
@@ -677,3 +685,11 @@ void interface_fullscreen(MainView *mainview) {
 	}
 }
 
+void interfaceCallLastItem(MainView *mainView) {
+#if MAEMO_VERSION_MAJOR < 5
+	g_signal_emit_by_name(G_OBJECT(mainView->open_last_item), "activate");
+#else
+	g_signal_emit_by_name(G_OBJECT(mainView->open_last_item), "clicked");
+#endif
+}
+
