@@ -36,6 +36,8 @@
 #include <hildon-widgets/hildon-app.h>
 #endif
 
+#include <mce/dbus-names.h>
+
 #include <src/appdata.h>
 
 #define _(String) gettext(String)
@@ -49,6 +51,8 @@
 
 #define MAIN_VIEW_NAME ""
 
+#define MCE_MATCH_RULE "type='signal',interface='" MCE_SIGNAL_IF "',member='" MCE_INACTIVITY_SIG "'"
+
 typedef enum {
 	PWSAFE_NO_ERROR = 0,
 	PWSAFE_ERROR_OPEN_FAILED,
@@ -135,8 +139,10 @@ struct _MainView
 	gchar* pass;			/* must be stored to be able to write file again... */
 	gchar *preferences;		/* preferences from the file... just written back out. */
 	RecWindow* rec_win;		/*active recwindow object... one per app */
+#if MAEMO_VERSION_MAJOR >= 5
 	GRegex *regexHttp;
 	GRegex *regexWww;
+#endif
 };
 
 /* Publics: */
@@ -156,5 +162,6 @@ void interface_show_state(MainView *main);
 char *emptynull(char *a);
 void interface_fullscreen(MainView *mainview);
 void interface_set_rec_editable(RecWindow* rec_win, gboolean editable);
+void interfaceCallLastItem(MainView *mainView) ;
 
 #endif
